@@ -32,9 +32,11 @@
 #include <errno.h>
 #include <string.h>
 
-#include "global.h"		/* home_dir */
-#include "../src/tty/tty.h"
-#include "../vfs/vfs.h"
+#include "lib/global.h"		/* home_dir */
+#include "lib/tty/tty.h"
+#include "lib/vfs/mc-vfs/vfs.h"
+#include "lib/strescape.h"
+
 #include "widget.h"		/* WInput */
 #include "command.h"
 #include "wtools.h"		/* message () */
@@ -44,9 +46,8 @@
 #include "user.h"		/* expand_format */
 #include "subshell.h"		/* SUBSHELL_EXIT */
 #include "tree.h"		/* for tree_chdir */
-#include "../src/skin/skin.h"		/* DEFAULT_COLOR */
+#include "lib/skin.h"		/* DEFAULT_COLOR */
 #include "execute.h"		/* shell_execute */
-#include "../src/strescape.h"
 
 /* This holds the command line */
 WInput *cmdline;
@@ -251,7 +252,7 @@ enter (WInput *lc_cmdline)
 	for (i = j = 0; i < cmd_len; i++) {
 	    if (cmd[i] == '%') {
 		i++;
-		s = expand_format (NULL, cmd[i], 1);
+		s = expand_format (NULL, cmd[i], TRUE);
 		command = g_realloc (command, j + strlen (s) + cmd_len - i + 1);
 		strcpy (command + j, s);
 		g_free (s);
