@@ -56,12 +56,14 @@
 #include <fcntl.h>
 #include <sys/time.h>
 
-#include "global.h"
-
-#include "../src/tty/tty.h"
-#include "../src/tty/key.h"
-
-#include "../src/search/search.h"
+#include "lib/global.h"
+#include "lib/tty/tty.h"
+#include "lib/tty/key.h"
+#include "lib/search.h"
+#include "lib/vfs/mc-vfs/vfs-impl.h"
+#include "lib/vfs/mc-vfs/vfs.h"
+#include "lib/strescape.h"
+#include "lib/strutil.h"
 
 #include "setup.h"
 #include "dialog.h"
@@ -71,8 +73,6 @@
 #include "widget.h"
 #include "wtools.h"
 #include "background.h"		/* we_are_background */
-#include "../src/strescape.h"
-#include "strutil.h"
 
 /* Needed for current_panel, other_panel and WTree */
 #include "dir.h"
@@ -80,8 +80,6 @@
 #include "file.h"
 #include "filegui.h"
 #include "tree.h"
-#include "../vfs/vfs-impl.h"
-#include "../vfs/vfs.h"
 
 /* }}} */
 
@@ -1818,8 +1816,7 @@ end_bg_process (FileOpContext *ctx, enum OperationMode mode) {
  * default destination.  Current filename is used as default.
  */
 int
-panel_operate (void *source_panel, FileOperation operation,
-	       int force_single)
+panel_operate (void *source_panel, FileOperation operation, int force_single)
 {
     WPanel *panel = (WPanel *) source_panel;
     const gboolean single_entry = force_single || (panel->marked <= 1)
