@@ -32,18 +32,19 @@
 #include <fcntl.h>
 #include <sys/stat.h>
 
-#include "global.h"
+#include "lib/global.h"
 
-#include "../src/tty/tty.h"
-#include "../src/skin/skin.h"
-#include "../src/tty/key.h"
-#include "../src/search/search.h"
-
-#include "../vfs/vfs.h"
+#include "lib/tty/tty.h"
+#include "lib/tty/key.h"
+#include "lib/skin.h"
+#include "lib/search.h"
+#include "lib/mcconfig.h"
+#include "lib/vfs/mc-vfs/vfs.h"
+#include "lib/strutil.h"
 
 #include "setup.h"
+#include "setup.h"		/* verbose */
 #include "find.h"
-#include "strutil.h"
 #include "dialog.h"
 #include "widget.h"
 #include "dir.h"
@@ -274,7 +275,6 @@ static int
 find_parameters (char **start_dir, char **pattern, char **content)
 {
     int return_value;
-    char *temp_dir = NULL;
 
     /* file name */
     const char *file_case_label = N_("Cas&e sensitive");
@@ -323,10 +323,10 @@ find_parameters (char **start_dir, char **pattern, char **content)
     b1 = str_term_width1 (buts[1]) + 4;
     b2 = str_term_width1 (buts[2]) + 4;
 
-  find_par_start:
     if (in_start_dir == NULL)
 	in_start_dir = g_strdup (".");
 
+  find_par_start:
     find_dlg =
 	create_dlg (0, 0, FIND_Y, FIND_X, dialog_colors,
 		    find_parm_callback, "[Find File]", _("Find File"),
@@ -399,6 +399,9 @@ find_parameters (char **start_dir, char **pattern, char **content)
 	break;
 
     case B_TREE:
+    {
+	char temp_dir[MC_MAXPATHLEN];
+	g_strlcpy (temp_dir, in_start->buffer, sizeof (temp_dir));
 #ifdef HAVE_CHARSET
 	file_all_charsets_flag = file_all_charsets_cbox->state & C_BOOL;
 	content_all_charsets_flag = content_all_charsets_cbox->state & C_BOOL;
@@ -411,24 +414,19 @@ find_parameters (char **start_dir, char **pattern, char **content)
 	file_case_sens_flag = file_case_sens_cbox->state & C_BOOL;
 	find_recurs_flag = recursively_cbox->state & C_BOOL;
 	skip_hidden_flag = skip_hidden_cbox->state & C_BOOL;
-
 	destroy_dlg (find_dlg);
+
+	if ((temp_dir[0] == '\0')
+		|| ((temp_dir[0] == '.') && (temp_dir[1] == '\0')))
+	    g_strlcpy (temp_dir, current_panel->cwd, sizeof (temp_dir));
+
 	if (in_start_dir != INPUT_LAST_TEXT)
 	    g_free (in_start_dir);
-	temp_dir = g_strdup (in_start->buffer);
-	if ((temp_dir[0] == '.') && (temp_dir[1] == '\0')) {
-	    g_free (temp_dir);
-	    temp_dir = g_strdup (current_panel->cwd);
-	}
 	in_start_dir = tree_box (temp_dir);
-	if (in_start_dir != NULL)
-	    g_free (temp_dir);
-	else
-	    in_start_dir = temp_dir;
 	/* Warning: Dreadful goto */
 	goto find_par_start;
 	break;
-
+    }
     default:
 #ifdef HAVE_CHARSET
 	file_all_charsets_flag = file_all_charsets_cbox->state & C_BOOL;
@@ -764,13 +762,13 @@ do_search (struct Dlg_head *h)
     search_content_handle = mc_search_new(content_pattern, -1);
     if (search_content_handle) {
         search_content_handle->search_type = (content_regexp_flag) ? MC_SEARCH_T_REGEX : MC_SEARCH_T_NORMAL;
-        search_content_handle->is_case_sentitive = content_case_sens_flag;
+        search_content_handle->is_case_sensitive = content_case_sens_flag;
         search_content_handle->whole_words = content_whole_words;
         search_content_handle->is_all_charsets = content_all_charsets_flag;
     }
     search_file_handle = mc_search_new(find_pattern, -1);
     search_file_handle->search_type = (file_pattern_flag) ?  MC_SEARCH_T_GLOB : MC_SEARCH_T_REGEX;
-    search_file_handle->is_case_sentitive = file_case_sens_flag;
+    search_file_handle->is_case_sensitive = file_case_sens_flag;
     search_file_handle->is_all_charsets = file_all_charsets_flag;
     search_file_handle->is_entire_line = file_pattern_flag;
 
