@@ -51,20 +51,21 @@
 #include <sys/types.h>
 #include <sys/stat.h>
 
-#include "global.h"
+#include "lib/global.h"
 
-#include "../src/tty/tty.h"
-#include "../src/skin/skin.h"
-#include "../src/tty/mouse.h"
-#include "../src/tty/key.h"
+#include "lib/tty/tty.h"
+#include "lib/skin.h"
+#include "lib/tty/mouse.h"
+#include "lib/tty/key.h"
+#include "lib/strutil.h"
 
 #include "dialog.h"		/* For Dlg_head */
 #include "widget.h"		/* For Widget */
 #include "wtools.h"		/* For common_dialog_repaint() */
-#include "strutil.h"
 #include "cmddef.h"
 #include "keybind.h"
 #include "help.h"
+#include "main.h"
 
 const global_keymap_t *help_map;
 
@@ -886,6 +887,14 @@ mousedispatch_new (int y, int x, int yl, int xl)
 void
 interactive_display (const char *filename, const char *node)
 {
+    const int help_colors[DLG_COLOR_NUM] =
+    {
+	HELP_NORMAL_COLOR,	/* common text color */
+	0,			/* unused in help */
+	HELP_BOLD_COLOR,	/* title color */
+	0			/* unused in help */
+    };
+
     WButtonBar *help_bar;
     Widget *md;
     char *hlpfile = NULL;
@@ -894,7 +903,7 @@ interactive_display (const char *filename, const char *node)
     if (filename != NULL)
 	filedata = load_file (filename);
     else
-	filedata = load_mc_home_file ("mc.hlp", &hlpfile);
+	filedata = load_mc_home_file (mc_home, mc_home_alt, "mc.hlp", &hlpfile);
 
     if (filedata == NULL)
 	message (D_ERROR, MSG_ERROR, _(" Cannot open file %s \n %s "), filename ? filename : hlpfile,
@@ -933,7 +942,7 @@ interactive_display (const char *filename, const char *node)
 
     whelp =
 	create_dlg (0, 0, help_lines + 4, HELP_WINDOW_WIDTH + 4,
-		    dialog_colors, help_callback, "[Help]", _("Help"),
+		    help_colors, help_callback, "[Help]", _("Help"),
 		    DLG_TRYUP | DLG_CENTER | DLG_WANT_TAB);
 
     selected_item = search_string_node (main_node, STRING_LINK_START) - 1;
