@@ -24,12 +24,14 @@
 
 #include <stdio.h>
 
-#include "global.h"
+#include "lib/global.h"
 
-#include "../src/tty/tty.h"
-#include "../src/tty/key.h"		/* is_idle() */
-#include "../src/tty/mouse.h"		/* Gpm_Event */
-#include "../src/skin/skin.h"
+#include "lib/tty/tty.h"
+#include "lib/tty/key.h"		/* is_idle() */
+#include "lib/tty/mouse.h"		/* Gpm_Event */
+#include "lib/skin.h"
+#include "lib/unixcompat.h"
+#include "lib/strutil.h"
 
 #include "dialog.h"
 #include "widget.h"		/* default_proc*/
@@ -38,11 +40,8 @@
 #include "panel.h"		/* for the panel structure */
 #include "main.h"		/* other_panel, current_panel definitions */
 #include "menu.h"		/* menubar_visible */
-#include "util.h"		/* size_trunc_len */
 #include "layout.h"
 #include "mountlist.h"
-#include "unixcompat.h"
-#include "strutil.h"
 #include "info.h"
 
 #ifndef VERSION
@@ -163,8 +162,10 @@ info_show_info (struct WInfo *info)
         g_string_set_size(buff, 0);
     case 9:
 	widget_move (&info->widget, 9, 3);
-	/* TRANSLATORS: "Status changed", like in the stat(2) man page */
-        str_printf (buff, _("Status:    %s"), file_date (st.st_ctime));
+        /* The field st_ctime is changed by writing or by setting inode
+           information (i.e., owner, group, link count, mode, etc.).  */
+        /* TRANSLATORS: Time of last status change as in stat(2) man. */
+        str_printf (buff, _("Changed:   %s"), file_date (st.st_ctime));
         tty_print_string (buff->str);
         g_string_set_size(buff, 0);
 
