@@ -39,18 +39,32 @@
 #include <unistd.h>
 #include <pwd.h>		/* for username in xterm title */
 
-#include "global.h"
+#include "lib/global.h"
 
-#include "../src/tty/tty.h"
-#include "../src/skin/skin.h"
-#include "../src/tty/mouse.h"
-#include "../src/tty/key.h"		/* For init_key() */
-#include "../src/tty/win.h"		/* xterm_flag */
+#include "lib/tty/tty.h"
+#include "lib/tty/mouse.h"
+#include "lib/tty/key.h"		/* For init_key() */
+#include "lib/tty/win.h"		/* xterm_flag */
 
-#include "../src/mcconfig/mcconfig.h"
-#include "../src/args.h"
-#include "../src/skin/skin.h"
-#include "../src/filehighlight/fhl.h"
+#include "lib/skin.h"
+
+#include "lib/mcconfig.h"
+#include "lib/filehighlight.h"
+#include "lib/fileloc.h"		/* MC_USERCONF_DIR */
+
+#include "lib/vfs/mc-vfs/vfs.h"		/* vfs_translate_url() */
+
+#ifdef ENABLE_VFS_SMB
+#include "lib/vfs/mc-vfs/smbfs.h"	/* smbfs_set_debug() */
+#endif /* ENABLE_VFS_SMB */
+
+#ifdef ENABLE_VFS
+#include "lib/vfs/mc-vfs/gc.h"
+#endif
+
+#include "lib/strutil.h"
+
+#include "src/args.h"
 
 #include "dir.h"
 #include "dialog.h"
@@ -59,7 +73,7 @@
 #include "option.h"
 #include "tree.h"
 #include "treestore.h"
-#include "cons.saver.h"
+#include "consaver/cons.saver.h"
 #include "subshell.h"
 #include "setup.h"		/* save_setup() */
 #include "boxes.h"		/* sort_box() */
@@ -71,15 +85,12 @@
 #include "listmode.h"
 #include "execute.h"
 #include "ext.h"		/* For flush_extension_file() */
-#include "strutil.h"
 #include "widget.h"
 #include "command.h"
 #include "wtools.h"
 #include "cmddef.h"		/* CK_ cmd name const */
-#include "fileloc.h"		/* MC_USERCONF_DIR */
 #include "user.h"		/* user_file_menu_cmd() */
 
-#include "../vfs/vfs.h"		/* vfs_translate_url() */
 
 #include "chmod.h"
 #include "chown.h"
@@ -87,21 +98,15 @@
 
 #include "main.h"
 
-#ifdef WITH_SMBFS
-#include "../vfs/smbfs.h"	/* smbfs_set_debug() */
-#endif
 
 #ifdef USE_INTERNAL_EDIT
-#   include "../edit/edit.h"
+#   include "src/editor/edit.h"
 #endif
 
 #ifdef	HAVE_CHARSET
 #include "charsets.h"
 #endif				/* HAVE_CHARSET */
 
-#ifdef ENABLE_VFS
-#include "../vfs/gc.h"
-#endif
 
 #include "keybind.h"		/* type global_keymap_t */
 
@@ -193,13 +198,8 @@ int mouse_move_pages = 1;
 /* If true: l&r arrows are used to chdir if the input line is empty */
 int navigate_with_arrows = 0;
 
-/* If true program softkeys (HP terminals only) on startup and after every
-   command ran in the subshell to the description found in the termcap/terminfo
-   database */
-int reset_hp_softkeys = 0;
-
 /* The prompt */
-const char *prompt = NULL;
+const char *mc_prompt = NULL;
 
 /* The widget where we draw the prompt */
 WLabel *the_prompt;
@@ -598,8 +598,8 @@ load_prompt (int fd, void *unused)
 	    tmp_prompt[COLS - 8] = '\0';
 	    prompt_len = COLS - 8;
 	}
-	prompt = tmp_prompt;
-	label_set_text (the_prompt, prompt);
+	mc_prompt = tmp_prompt;
+	label_set_text (the_prompt, mc_prompt);
 	winput_set_origin ((WInput *) cmdline, prompt_len,
 			   COLS - prompt_len);
 
@@ -692,9 +692,9 @@ create_panel_menu (void)
 #endif
     entries = g_list_append (entries, menu_entry_create (_("FT&P link..."),     CK_FtplinkCmd));
     entries = g_list_append (entries, menu_entry_create (_("S&hell link..."),   CK_FishlinkCmd));
-#ifdef WITH_SMBFS
+#ifdef ENABLE_VFS_SMB
     entries = g_list_append (entries, menu_entry_create (_("SM&B link..."),     CK_SmblinkCmd));
-#endif
+#endif /* ENABLE_VFS_SMB */
 #endif
     entries = g_list_append (entries, menu_separator_create ());
     entries = g_list_append (entries, menu_entry_create (_("&Rescan"),          CK_RereadCmd));
@@ -925,11 +925,8 @@ create_panels (void)
 {
     int current_index;
     int other_index;
-    int current_mode;
-    int other_mode;
-    char original_dir[1024];
-
-    original_dir[0] = 0;
+    panel_view_mode_t current_mode, other_mode;
+    char original_dir[BUF_1K] = "\0";
 
     if (boot_current_is_left) {
 	current_index = 0;
@@ -957,7 +954,7 @@ create_panels (void)
 
     /* The other panel */
     if (other_dir) {
-	if (original_dir[0])
+	if (original_dir[0] != '\0')
 	    translated_mc_chdir (original_dir);
 	translated_mc_chdir (other_dir);
     }
@@ -974,7 +971,7 @@ create_panels (void)
 
     /* Create the nice widgets */
     cmdline = command_new (0, 0, 0);
-    the_prompt = label_new (0, 0, prompt);
+    the_prompt = label_new (0, 0, mc_prompt);
     the_prompt->transparent = 1;
     the_bar = buttonbar_new (keybar_visible);
 
@@ -1049,9 +1046,8 @@ copy_current_readlink (void)
 static void
 copy_other_readlink (void)
 {
-    if (get_other_type () != view_listing)
-	return;
-    copy_readlink (other_panel);
+    if (get_other_type () == view_listing)
+	copy_readlink (other_panel);
 }
 
 /* Insert the selected file name into the input line */
@@ -1100,9 +1096,8 @@ copy_current_tagged (void)
 static void
 copy_other_tagged (void)
 {
-    if (get_other_type () != view_listing)
-	return;
-    copy_tagged (other_panel);
+    if (get_other_type () == view_listing)
+	copy_tagged (other_panel);
 }
 
 void
@@ -1321,11 +1316,11 @@ midnight_execute_cmd (Widget *sender, unsigned long command)
     case CK_SingleDirsizeCmd:
         smart_dirsize_cmd ();
         break;
-#if defined (USE_NETCODE) && defined (WITH_SMBFS)
+#if defined (USE_NETCODE) && defined (ENABLE_VFS_SMB)
     case CK_SmblinkCmd:
         smblink_cmd ();
         break;
-#endif
+#endif /* USE_NETCODE && ENABLE_VFS_SMB */
     case CK_Sort:
         sort_cmd ();
         break;
@@ -1377,18 +1372,6 @@ midnight_execute_cmd (Widget *sender, unsigned long command)
     return res;
 }
 
-static void
-setup_pre (void)
-{
-    /* Call all the inits */
-
-#ifdef HAVE_SLANG
-    tty_display_8bit (full_eight_bits != 0);
-#else
-    tty_display_8bit (eight_bit_clean != 0);
-#endif
-}
-
 static void
 init_xterm_support (void)
 {
@@ -1437,9 +1420,11 @@ init_xterm_support (void)
 static void
 setup_mc (void)
 {
-    setup_pre ();
-    create_panels ();
-    setup_panels ();
+#ifdef HAVE_SLANG
+    tty_display_8bit (full_eight_bits != 0);
+#else
+    tty_display_8bit (eight_bit_clean != 0);
+#endif
 
 #ifdef HAVE_SUBSHELL_SUPPORT
     if (use_subshell)
@@ -1448,7 +1433,8 @@ setup_mc (void)
 
     tty_setup_sigwinch (sigwinch_handler);
 
-    verbose = !((tty_baudrate () < 9600) || tty_is_slow ());
+    if ((tty_baudrate () < 9600) || tty_is_slow ())
+	verbose = 0;
 
     init_xterm_support ();
     init_mouse ();
@@ -1540,6 +1526,9 @@ midnight_callback (Dlg_head *h, Widget *sender,
     unsigned long command;
 
     switch (msg) {
+    case DLG_INIT:
+	setup_panels ();
+	return MSG_HANDLED;
 
     case DLG_DRAW:
 	load_hint (1);
@@ -1558,6 +1547,12 @@ midnight_callback (Dlg_head *h, Widget *sender,
     case DLG_IDLE:
 	/* We only need the first idle event to show user menu after start */
 	set_idle_proc (h, 0);
+
+	if (boot_current_is_left)
+	    dlg_select_widget (get_panel_widget (0));
+	else
+	    dlg_select_widget (get_panel_widget (1));
+
 	if (auto_menu)
 	    midnight_execute_cmd (NULL, CK_UserMenuCmd);
 	return MSG_HANDLED;
@@ -1765,15 +1760,18 @@ load_hint (int force)
 }
 
 static void
-setup_panels_and_run_mc (void)
+create_panels_and_run_mc (void)
 {
     midnight_dlg->get_shortcut = midnight_get_shortcut;
 
+    create_panels ();
+
     add_widget (midnight_dlg, the_menubar);
     init_menu ();
 
     add_widget (midnight_dlg, get_panel_widget (0));
     add_widget (midnight_dlg, get_panel_widget (1));
+
     add_widget (midnight_dlg, the_hint);
     add_widget (midnight_dlg, cmdline);
     add_widget (midnight_dlg, the_prompt);
@@ -1781,11 +1779,6 @@ setup_panels_and_run_mc (void)
     add_widget (midnight_dlg, the_bar);
     midnight_set_buttonbar (the_bar);
 
-    if (boot_current_is_left)
-	dlg_select_widget (get_panel_widget (0));
-    else
-	dlg_select_widget (get_panel_widget (1));
-
     /* Run the Midnight Commander if no file was specified in the command line */
     run_dlg (midnight_dlg);
 }
@@ -1795,45 +1788,39 @@ static char *
 prepend_cwd_on_local (const char *filename)
 {
     char *d;
-    int l;
+    size_t l;
 
-    if (vfs_file_is_local (filename)) {
-	if (*filename == PATH_SEP)	/* an absolute pathname */
-	    return g_strdup (filename);
-	d = g_malloc (MC_MAXPATHLEN + strlen (filename) + 2);
-	mc_get_current_wd (d, MC_MAXPATHLEN);
-	l = strlen (d);
-	d[l++] = PATH_SEP;
-	strcpy (d + l, filename);
-	canonicalize_pathname (d);
-	return d;
-    } else
+    if (!vfs_file_is_local (filename)
+	|| g_path_is_absolute (filename))
 	return g_strdup (filename);
+
+    d = g_malloc (MC_MAXPATHLEN + strlen (filename) + 2);
+    mc_get_current_wd (d, MC_MAXPATHLEN);
+    l = strlen (d);
+    d[l++] = PATH_SEP;
+    strcpy (d + l, filename);
+    canonicalize_pathname (d);
+    return d;
 }
 
-static int
+/* Invoke the internal view/edit routine with:
+ * the default processing and forcing the internal viewer/editor
+ */
+static void
 mc_maybe_editor_or_viewer (void)
 {
-    if (!(view_one_file || edit_one_file))
-	return 0;
-
-    /* Invoke the internal view/edit routine with:
-     * the default processing and forcing the internal viewer/editor
-     */
-    if (view_one_file) {
-	char *path = NULL;
+    if (view_one_file != NULL) {
+	char *path;
 	path = prepend_cwd_on_local (view_one_file);
 	view_file (path, 0, 1);
 	g_free (path);
     }
 #ifdef USE_INTERNAL_EDIT
-    else {
+    else
 	edit_file (edit_one_file, edit_one_file_start_line);
-    }
 #endif				/* USE_INTERNAL_EDIT */
     midnight_shutdown = 1;
     done_mc ();
-    return 1;
 }
 
 /* Run the main dialog that occupies the whole screen */
@@ -1851,7 +1838,7 @@ do_nc (void)
     midnight_dlg = create_dlg (0, 0, LINES, COLS, midnight_colors, midnight_callback,
 			       "[main]", NULL, DLG_WANT_IDLE);
 
-    if (view_one_file || edit_one_file)
+    if ((view_one_file != NULL) || (edit_one_file != NULL))
 	setup_dummy_mc ();
     else
 	setup_mc ();
@@ -1884,8 +1871,10 @@ do_nc (void)
         help_map = (global_keymap_t *) help_keymap->data;
 
     /* Check if we were invoked as an editor or file viewer */
-    if (!mc_maybe_editor_or_viewer ()) {
-	setup_panels_and_run_mc ();
+    if ((view_one_file != NULL) || (edit_one_file != NULL))
+	mc_maybe_editor_or_viewer ();
+    else {
+	create_panels_and_run_mc ();
 
 	/* Program end */
 	midnight_shutdown = 1;
@@ -2018,15 +2007,15 @@ mc_main__setup_by_args (int argc, char *argv[])
 #ifdef USE_NETCODE
     if (mc_args__netfs_logfile != NULL) {
 	mc_setctl ("/#ftp:", VFS_SETCTL_LOGFILE, (void *) mc_args__netfs_logfile);
-#ifdef WITH_SMBFS
+#ifdef ENABLE_VFS_SMB
 	smbfs_set_debugf (mc_args__netfs_logfile);
-#endif				/* WITH_SMBFS */
+#endif				/* ENABLE_VFS_SMB */
     }
 
-#ifdef WITH_SMBFS
+#ifdef ENABLE_VFS_SMB
     if (mc_args__debug_level != 0)
 	smbfs_set_debug (mc_args__debug_level);
-#endif				/* WITH_SMBFS */
+#endif				/* ENABLE_VFS_SMB */
 #endif				/* USE_NETCODE */
 
     base = x_basename (argv[0]);
@@ -2137,7 +2126,7 @@ main (int argc, char *argv[])
 
 #ifdef HAVE_SUBSHELL_SUPPORT
     /* Don't use subshell when invoked as viewer or editor */
-    if (edit_one_file || view_one_file)
+    if ((view_one_file != NULL) || (edit_one_file != NULL))
 	use_subshell = 0;
 
     if (use_subshell)
@@ -2202,13 +2191,12 @@ main (int argc, char *argv[])
 
 #ifdef HAVE_SUBSHELL_SUPPORT
     if (use_subshell) {
-	prompt = strip_ctrl_codes (subshell_prompt);
-	if (!prompt)
-	    prompt = "";
+	mc_prompt = strip_ctrl_codes (subshell_prompt);
+	if (mc_prompt == NULL)
+	    mc_prompt = (geteuid () == 0) ? "# " : "$ ";
     } else
 #endif				/* HAVE_SUBSHELL_SUPPORT */
-	prompt = (geteuid () == 0) ? "# " : "$ ";
-
+	mc_prompt = (geteuid () == 0) ? "# " : "$ ";
 
     /* Program main loop */
     if (!midnight_shutdown)
