@@ -6,16 +6,17 @@
    2004, 2005, 2006, 2007, 2009 Free Software Foundation, Inc.
 
    Written by: 1994, 1995, 1998 Miguel de Icaza
-	       1994, 1995 Janne Kukonlehto
-	       1995 Jakub Jelinek
-	       1996 Joseph M. Hinkle
-	       1997 Norbert Warmuth
-	       1998 Pavel Machek
-	       2004 Roland Illig <roland.illig@gmx.de>
-	       2005 Roland Illig <roland.illig@gmx.de>
-	       2009 Slava Zanko <slavazanko@google.com>
-	       2009 Andrew Borodin <aborodin@vmail.ru>
-	       2009 Ilia Maslakov <il.smind@gmail.com>
+   1994, 1995 Janne Kukonlehto
+   1995 Jakub Jelinek
+   1996 Joseph M. Hinkle
+   1997 Norbert Warmuth
+   1998 Pavel Machek
+   2004 Roland Illig <roland.illig@gmx.de>
+   2005 Roland Illig <roland.illig@gmx.de>
+   2009 Slava Zanko <slavazanko@google.com>
+   2009 Andrew Borodin <aborodin@vmail.ru>
+   2009 Ilia Maslakov <il.smind@gmail.com>
+   2010 Andrew Borodin <aborodin@vmail.ru>
 
    This file is part of the Midnight Commander.
 
@@ -37,11 +38,15 @@
 
 #include <config.h>
 
-#include "../src/global.h"
-#include "../src/main.h"
-#include "../src/charsets.h"
-#include "../src/tty/tty.h"
-#include "../src/skin/skin.h"
+#include "lib/tty/tty.h"
+
+#include "lib/skin.h"
+
+#include "lib/global.h"
+#include "src/main.h"
+#include "src/charsets.h"
+#include "mcviewer.h"           /* mcview_show_eof */
+
 #include "internal.h"
 
 /*** global variables ****************************************************************************/
@@ -65,7 +70,7 @@ mcview_display_text (mcview_t * view)
     const screen_dimen top = view->data_area.top;
     const screen_dimen width = view->data_area.width;
     const screen_dimen height = view->data_area.height;
-    screen_dimen row, col;
+    screen_dimen row = 0, col = 0;
     off_t from;
     int cw = 1;
     int c, prev_ch = 0;
@@ -76,92 +81,115 @@ mcview_display_text (mcview_t * view)
 
     /* Find the first displayable changed byte */
     from = view->dpy_start;
-    while (curr && (curr->offset < from)) {
+    while ((curr != NULL) && (curr->offset < from))
         curr = curr->next;
-    }
 
-    tty_setcolor (NORMAL_COLOR);
-    for (row = 0, col = 0; row < height;) {
+    while (TRUE)
+    {
+        tty_setcolor (NORMAL_COLOR);
+
+        if (row >= height)
+            break;
+
 #ifdef HAVE_CHARSET
-        if (view->utf8) {
+        if (view->utf8)
+        {
             gboolean read_res = TRUE;
+
             c = mcview_get_utf (view, from, &cw, &read_res);
             if (!read_res)
                 break;
-        } else
-#endif
-        {
-            if (! mcview_get_byte (view, from, &c))
-                break;
         }
+        else
+#endif
+        if (!mcview_get_byte (view, from, &c))
+            break;
+
         from++;
         if (cw > 1)
             from += cw - 1;
 
-        if (c != '\n' && prev_ch == '\r') {
+        if (c != '\n' && prev_ch == '\r')
+        {
+            if (++row >= height)
+                break;
+
             col = 0;
-            row++;
-            tty_print_anychar ('\n');
+            /* tty_print_anychar ('\n'); */
         }
 
         prev_ch = c;
         if (c == '\r')
             continue;
 
-        if ((c == '\n') || (col >= width && view->text_wrap_mode)) {
+        if (c == '\n')
+        {
             col = 0;
             row++;
-            if (c == '\n' || row >= height)
-                continue;
+            continue;
         }
 
-        if (c == '\t') {
+        if (col >= width && view->text_wrap_mode)
+        {
+            col = 0;
+            if (++row >= height)
+                break;
+        }
+
+        if (c == '\t')
+        {
             off_t line, column;
             mcview_offset_to_coord (view, &line, &column, from);
             col += (option_tab_spacing - col % option_tab_spacing);
-            if (view->text_wrap_mode && col >= width && width != 0) {
+            if (view->text_wrap_mode && col >= width && width != 0)
+            {
                 row += col / width;
                 col %= width;
             }
             continue;
         }
 
-        if (view->search_start <= from && from < view->search_end) {
+        if (view->search_start <= from && from < view->search_end)
             tty_setcolor (SELECTED_COLOR);
-        }
 
-        if (col >= view->dpy_text_column && col - view->dpy_text_column < width) {
+        if ((col >= view->dpy_text_column) && (col - view->dpy_text_column < width))
+        {
             widget_move (view, top + row, left + (col - view->dpy_text_column));
 #ifdef HAVE_CHARSET
-            if (utf8_display) {
-                if (!view->utf8) {
-                    c = convert_from_8bit_to_utf_c (c, view->converter);
-                }
+            if (utf8_display)
+            {
+                if (!view->utf8)
+                    c = convert_from_8bit_to_utf_c ((unsigned char) c, view->converter);
                 if (!g_unichar_isprint (c))
                     c = '.';
-            } else {
-                if (view->utf8) {
-                    c = convert_from_utf_to_current_c (c, view->converter);
-                } else {
-#endif
-                    c = convert_to_display_c (c);
-#ifdef HAVE_CHARSET
-                }
             }
+            else if (view->utf8)
+                c = convert_from_utf_to_current_c (c, view->converter);
+            else
 #endif
+            {
+                c = convert_to_display_c (c);
+
+                if (!is_printable (c))
+                    c = '.';
+            }
+
             tty_print_anychar (c);
         }
+
         col++;
+
 #ifdef HAVE_CHARSET
-        if (view->utf8) {
-            if (g_unichar_iswide(c))
+        if (view->utf8)
+        {
+            if (g_unichar_iswide (c))
                 col++;
-            else if (g_unichar_iszerowidth(c))
+            else if (g_unichar_iszerowidth (c))
                 col--;
         }
 #endif
-        tty_setcolor (NORMAL_COLOR);
     }
+
     view->dpy_end = from;
 }
 
