@@ -40,24 +40,23 @@
 #include <fcntl.h>
 #include <sys/types.h>
 
-#include "global.h"
+#include "lib/global.h"
 
-#include "../src/tty/tty.h"
-#include "../src/skin/skin.h"
-#include "../src/tty/mouse.h"
-#include "../src/tty/key.h"	/* XCTRL and ALT macros  */
-#include "../src/mcconfig/mcconfig.h"	/* for history loading and saving */
-
-#include "../vfs/vfs.h"
+#include "lib/tty/tty.h"
+#include "lib/skin.h"
+#include "lib/tty/mouse.h"
+#include "lib/tty/key.h"	/* XCTRL and ALT macros  */
+#include "lib/mcconfig.h"	/* for history loading and saving */
+#include "lib/vfs/mc-vfs/vfs.h"
+#include "lib/fileloc.h"
+#include "lib/strutil.h"
 
 #include "dialog.h"
 #include "widget.h"
 #include "wtools.h"
-#include "strutil.h"
 
 #include "cmddef.h"		/* CK_ cmd name const */
 #include "keybind.h"		/* global_keymap_t */
-#include "fileloc.h"
 #include "panel.h"		/* current_panel */
 
 const global_keymap_t *input_map;
@@ -915,7 +914,7 @@ static void draw_history_button (WInput * in)
 
 /* Input widgets now have a global kill ring */
 /* Pointer to killed data */
-static char *kill_buffer = 0;
+static char *kill_buffer = NULL;
 
 void
 update_input (WInput *in, int clear_first)
@@ -1018,9 +1017,9 @@ history_get (const char *input_name)
     g_strfreev (keys);
 
     for (i = 0; i < keys_num; i++) {
-	char key_name[BUF_TINY];
-	g_snprintf (key_name, sizeof (key_name), "%lu", (unsigned long)i);
-	this_entry = mc_config_get_string (cfg, input_name, key_name, "");
+	char key[BUF_TINY];
+	g_snprintf (key, sizeof (key), "%lu", (unsigned long)i);
+	this_entry = mc_config_get_string (cfg, input_name, key, "");
 
 	if (this_entry != NULL)
 	    hist = list_append_unique (hist, this_entry);
@@ -1081,9 +1080,9 @@ history_put (const char *input_name, GList *h)
 
 	/* We shouldn't have null entries, but let's be sure */
 	if (text != NULL) {
-	    char key_name[BUF_TINY];
-	    g_snprintf (key_name, sizeof (key_name), "%d", i++);
-	    mc_config_set_string(cfg,input_name, key_name, text);
+	    char key[BUF_TINY];
+	    g_snprintf (key, sizeof (key), "%d", i++);
+	    mc_config_set_string (cfg, input_name, key, text);
 	}
     }
 
@@ -1261,15 +1260,15 @@ do_show_hist (WInput *in)
 static void
 input_destroy (WInput *in)
 {
-    if (!in){
+    if (in == NULL){
 	fprintf (stderr, "Internal error: null Input *\n");
 	exit (1);
     }
 
     new_input (in);
 
-    if (in->history){
-	if (!in->is_password)	/* don't save passwords ;-) */
+    if (in->history != NULL){
+	if (!in->is_password && (((Widget *) in)->parent->ret_value != B_CANCEL))
 	    history_put (in->history_name, in->history);
 
 	in->history = g_list_first (in->history);
@@ -1280,6 +1279,9 @@ input_destroy (WInput *in)
     g_free (in->buffer);
     free_completions (in);
     g_free (in->history_name);
+
+    g_free (kill_buffer);
+    kill_buffer = NULL;
 }
 
 void
@@ -1651,14 +1653,14 @@ clear_region (WInput *in)
 static void
 yank (WInput *in)
 {
-    char *p;
+    if (kill_buffer != NULL) {
+	char *p;
 
-    if (!kill_buffer)
-        return;
-    in->charpoint = 0;
-    for (p = kill_buffer; *p; p++)
-	insert_char (in, *p);
-    in->charpoint = 0;
+	in->charpoint = 0;
+	for (p = kill_buffer; *p != '\0'; p++)
+	    insert_char (in, *p);
+	in->charpoint = 0;
+    }
 }
 
 static void
@@ -1702,18 +1704,20 @@ assign_text (WInput *in, const char *text)
 static void
 hist_prev (WInput *in)
 {
+    GList *prev;
+
     if (!in->history)
 	return;
 
-    if (in->need_push) {
+    if (in->need_push)
 	push_history (in, in->buffer);
-	in->history = g_list_previous (in->history);
-    } else if (in->history->prev)
-	in->history = g_list_previous (in->history);
-    else
-	return;
-    assign_text (in, (char *) in->history->data);
-    in->need_push = 0;
+
+    prev = g_list_previous (in->history);
+    if (prev != NULL) {
+	in->history = prev;
+	assign_text (in, (char *) prev->data);
+	in->need_push = 0;
+    }
 }
 
 static void
