@@ -6,7 +6,7 @@
 #ifndef MC_WIDGET_H
 #define MC_WIDGET_H
 
-#include "global.h"
+#include "lib/global.h"
 #include "dialog.h"		/* Widget */
 
 /* Completion stuff */
@@ -248,7 +248,7 @@ char *listbox_add_item (WListbox *l, enum append_pos pos, int
 struct global_keymap_t;
 
 WButtonBar *find_buttonbar (const Dlg_head *h);
-void buttonbar_set_label (WButtonBar *bb, int index, const char *text,
+void buttonbar_set_label (WButtonBar *bb, int idx, const char *text,
 			    const struct global_keymap_t *keymap, const Widget *receiver);
 #define buttonbar_clear_label(bb, idx, recv) buttonbar_set_label (bb, idx, "", NULL, recv)
 void buttonbar_set_visible (WButtonBar *bb, gboolean visible);
